# TPU - Tab Processing Unit

TPU is a set of awesome scripts that aim to facilitate musicians with programming background ;)

## Supported Features
- Tab Transposition with Semitone Offset

## Upcoming Features
- [ ] Tab Transposition with Single Chord Base

## FAQ

### Who is this package intended for?

Hmm, anyone interested really... :D

 TPU is intended to be used by _musicians_ but its core goal includes defining a more general processing unit for several tab related operations as well. You can think of it as a _building block_ for greater stuff!

### Can I contribute?

Definitely! Pull Requests are always more than welcome!

### What kind of help is needed?

Honestly, there are no constraints... Found a bug? Came up with a super cool idea for a new feature? Wanna help out with documentation? Can write some more testing?

**YES, PLEASE!**
